{ pkgs, ... }: {

  imports = [
    ./crypto.nix
    ./design.nix
    ./espanso.nix
    ./extrafonts.nix
    ./media.nix
    ./office.nix
    ./qt.nix
    ./syncthing.nix
    ./waybar.nix
    ./wofi.nix
  ];

  xdg.mimeApps = {
    enable = true;
    defaultApplications = { "application/pdf" = [ "okular.desktop" ]; };
  };

  home.sessionVariables = {
    WEBKIT_DISABLE_COMPOSITING_MODE = "1";
    NIXOS_OZONE_WL = "1";
    EDITOR = "emacs";
    VISUAL = "emacs";
    QT_QPA_PLATFORM = "wayland";
    XDG_CONFIG_HOME = "\${HOME}/.config";
    XDG_BIN_HOME = "\${HOME}/.local/bin";
    XDG_DATA_HOME = "\${HOME}/.local/share";
  };
  home.sessionPath =
    [ "\${XDG_BIN_HOME}" "\${HOME}/.cargo/bin" "$HOME/.npm-global/bin" ];

  fonts.fontconfig.enable = true;

  services.mako = {
    enable = true;
    backgroundColor = "#282a36";
    textColor = "#80FFEA";
    borderColor = "#9742b5";
    width = 400;
    height = 150;
    padding = "10,20";
    borderRadius = 8;
    borderSize = 1;
    margin = "20,20";
  };

  home.packages = with pkgs; [
    alacritty
    appimage-run
    blueberry
    brave
    brightnessctl
    clipman
    distrobox
    flameshot
    firefox
    fuzzel
    gnome.file-roller
    gnome.nautilus
    gnome.seahorse
    gnome.sushi
    gnome.vinagre
    glib
    gsettings-desktop-schemas
    hyprpaper
    pamixer
    pavucontrol
    picom
    libsForQt5.qtstyleplugins
    qt5ct
    rustdesk
    tor-browser-bundle-bin
    transmission-gtk
    ungoogled-chromium
    unrar
    unzip
    usbutils
    v4l-utils
    wl-clipboard
    wlogout
    wtype
    xdg-utils
    xdotool
    ydotool
    zip
  ];

}
